@@ -1,2 +1,2 @@
 from .github_data_repo import get_data_from_github
-from .github_data_repo import GithubDataRepo
+from .github_data_repo import GitHubDataRepo
